<?php
/**
 * Design Settings panel at Theme Customizer
 *
 * @package CodeVibrant
 * @subpackage Yaatra Mag
 * @since 1.0.0
 */

add_action( 'customize_register', 'yaatra_mag_design_settings_register' );

function yaatra_mag_design_settings_register( $wp_customize ) {

    $wp_customize->register_control_type( 'Yaatra_Mag_Customize_Control_Radio_Image' );

    /**
     * Add Design Settings Panel
     *
     * @since 1.0.0
     */
    $wp_customize->add_panel(
	    'yaatra_mag_design_settings_panel',
	    array(
	        'priority'       => 20,
	        'capability'     => 'edit_theme_options',
	        'theme_supports' => '',
	        'title'          => __( 'Design Settings', 'yaatra-mag' ),
	    )
    );

/*----------------------------------------------------------------------------------------------------------------------------------------*/
	/**
     * Archive section
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'yaatra_mag_archive_section',
        array(
        	'priority'       => 5,
        	'panel'          => 'yaatra_mag_design_settings_panel',
        	'capability'     => 'edit_theme_options',
        	'theme_supports' => '',
            'title'          => __( 'Archive Section', 'yaatra-mag' )
        )
    );

    /**
     * Radio image field for archive sidebar
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yaatra_mag_archive_sidebar',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => 'right_sidebar',
            'sanitize_callback' => 'yaatra_mag_sanitize_select',
        )
    );
    $wp_customize->add_control( new Yaatra_Mag_Customize_Control_Radio_Image(
        $wp_customize,
        'yaatra_mag_archive_sidebar',
            array(
                'label'         => __( 'Archive Sidebars', 'yaatra-mag' ),
                'description'   => __( 'Choose sidebar from available layouts', 'yaatra-mag' ),
                'section'       => 'yaatra_mag_archive_section',
                'settings'      => 'yaatra_mag_archive_sidebar',
                'priority'      => 5,
                'choices'       => array(
                    'left_sidebar'      => array(
                        'label'         => __( 'Left Sidebar', 'yaatra-mag' ),
                        'url'           => '%s/assets/images/left-sidebar.png'
                    ),
                    'right_sidebar'     => array(
                        'label'         => __( 'Right Sidebar', 'yaatra-mag' ),
                        'url'           => '%s/assets/images/right-sidebar.png'
                    ),
                    'no_sidebar'        => array(
                        'label'         => __( 'No Sidebar', 'yaatra-mag' ),
                        'url'           => '%s/assets/images/no-sidebar.png'
                    )
                )
            )
        )
    );

    /**
     * Image Radio field for archive layout
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yaatra_mag_archive_layout',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => 'grid',
            'sanitize_callback' => 'yaatra_mag_sanitize_select',
        )
    );
    $wp_customize->add_control( new Yaatra_Mag_Customize_Control_Radio_Image(
        $wp_customize,
        'yaatra_mag_archive_layout',
            array(
                'label'         => __( 'Archive Layouts', 'yaatra-mag' ),
                'description'   => __( 'Choose layout from available layouts', 'yaatra-mag' ),
                'section'       => 'yaatra_mag_archive_section',
                'settings'      => 'yaatra_mag_archive_layout',
                'priority'      => 10,
                'choices'       => array(
                    'classic'   => array(
                        'label' => __( 'Classic', 'yaatra-mag' ),
                        'url'   => '%s/assets/images/archive-classic.png'
                    ),
                    'grid'   => array(
                        'label' => __( 'Grid', 'yaatra-mag' ),
                        'url'   => '%s/assets/images/archive-layout2.png'
                    ),
                    'classic-grid' => array(
                        'label' => __( 'Classic Grid', 'yaatra-mag' ),
                        'url'   => '%s/assets/images/archive-layout1.png'
                    )
                ),
                
            )
        )
    );

/*----------------------------------------------------------------------------------------------------------------------------------------*/
    /**
     * Page Settings
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'yaatra_mag_page_section',
        array(
            'priority'       => 10,
            'panel'          => 'yaatra_mag_design_settings_panel',
            'capability'     => 'edit_theme_options',
            'theme_supports' => '',
            'title'          => __( 'Page Settings', 'yaatra-mag' )
        )
    );      

    /**
     * Radio image field for page sidebar
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yaatra_mag_global_page_sidebar',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => 'right_sidebar',
            'sanitize_callback' => 'yaatra_mag_sanitize_select',
        )
    );
    $wp_customize->add_control( new Yaatra_Mag_Customize_Control_Radio_Image(
        $wp_customize,
        'yaatra_global_page_sidebar',
            array(
                'label'         => __( 'Page Sidebars', 'yaatra-mag' ),
                'description'   => __( 'Choose sidebar from available layouts', 'yaatra-mag' ),
                'section'       => 'yaatra_mag_page_section',
                'settings'      => 'yaatra_mag_global_page_sidebar',
                'priority'      => 5,
                'choices'       => array(
                    'left_sidebar'      => array(
                        'label'         => __( 'Left Sidebar', 'yaatra-mag' ),
                        'url'           => '%s/assets/images/left-sidebar.png'
                    ),
                    'right_sidebar'     => array(
                        'label'         => __( 'Right Sidebar', 'yaatra-mag' ),
                        'url'           => '%s/assets/images/right-sidebar.png'
                    ),
                    'no_sidebar'        => array(
                        'label'         => __( 'No Sidebar', 'yaatra-mag' ),
                        'url'           => '%s/assets/images/no-sidebar.png'
                    )
                )
            )
        )
    );

    /**
     * Image Radio field for page style
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yaatra_mag_page_style',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => 'style_one',
            'sanitize_callback' => 'yaatra_mag_sanitize_select',
        )
    );
    $wp_customize->add_control( new Yaatra_Mag_Customize_Control_Radio_Image(
        $wp_customize,
        'yaatra_mag_page_style',
            array(
                'label'         => __( 'Page Styles', 'yaatra-mag' ),
                'description'   => __( 'Choose layout from available layouts', 'yaatra-mag' ),
                'section'       => 'yaatra_mag_page_section',
                'settings'      => 'yaatra_mag_page_style',
                'priority'      => 10,
                'choices'       => array(
                    'style_one'   => array(
                        'label' => __( 'Style One', 'yaatra-mag' ),
                        'url'   => '%s/assets/images/post-style-one.png'
                    ),
                    'style_two'   => array(
                        'label' => __( 'Style Two', 'yaatra-mag' ),
                        'url'   => '%s/assets/images/post-style-two.png'
                    )
                ),
                
            )
        )
    );

/*----------------------------------------------------------------------------------------------------------------------------------------*/
    /**
     * Post Settings
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'yaatra_mag_post_section',
        array(
            'priority'       => 15,
            'panel'          => 'yaatra_mag_design_settings_panel',
            'capability'     => 'edit_theme_options',
            'theme_supports' => '',
            'title'          => __( 'Post Settings', 'yaatra-mag' )
        )
    );      

    /**
     * Radio image field for page sidebar
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yaatra_mag_global_post_sidebar',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => 'right_sidebar',
            'sanitize_callback' => 'yaatra_mag_sanitize_select',
        )
    );
    $wp_customize->add_control( new Yaatra_Mag_Customize_Control_Radio_Image(
        $wp_customize,
        'yaatra_mag_global_post_sidebar',
            array(
                'label'         => __( 'Post Sidebars', 'yaatra-mag' ),
                'description'   => __( 'Choose sidebar from available layouts', 'yaatra-mag' ),
                'section'       => 'yaatra_mag_post_section',
                'settings'      => 'yaatra_mag_global_post_sidebar',
                'priority'      => 5,
                'choices'       => array(
                    'left_sidebar'      => array(
                        'label'         => __( 'Left Sidebar', 'yaatra-mag' ),
                        'url'           => '%s/assets/images/left-sidebar.png'
                    ),
                    'right_sidebar'     => array(
                        'label'         => __( 'Right Sidebar', 'yaatra-mag' ),
                        'url'           => '%s/assets/images/right-sidebar.png'
                    ),
                    'no_sidebar'        => array(
                        'label'         => __( 'No Sidebar', 'yaatra-mag' ),
                        'url'           => '%s/assets/images/no-sidebar.png'
                    )
                )
            )
        )
    );

    /**
     * Image Radio field for post style
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yaatra_mag_post_style',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => 'style_one',
            'sanitize_callback' => 'yaatra_mag_sanitize_select',
        )
    );
    $wp_customize->add_control( new Yaatra_Mag_Customize_Control_Radio_Image(
        $wp_customize,
        'yaatra_mag_post_style',
            array(
                'label'         => __( 'Post Styles', 'yaatra-mag' ),
                'description'   => __( 'Choose layout from available layouts', 'yaatra-mag' ),
                'section'       => 'yaatra_mag_post_section',
                'settings'      => 'yaatra_mag_post_style',
                'priority'      => 10,
                'choices'       => array(
                    'style_one'   => array(
                        'label' => __( 'Style One', 'yaatra-mag' ),
                        'url'   => '%s/assets/images/post-style-one.png'
                    ),
                    'style_two'   => array(
                        'label' => __( 'Style Two', 'yaatra-mag' ),
                        'url'   => '%s/assets/images/post-style-two.png'
                    )
                ),
                
            )
        )
    );

    /**
     * Checkbox for related posts section at post page
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yaatra_mag_enable_related_posts',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => true,
            'sanitize_callback' => 'yaatra_mag_sanitize_checkbox',
        )
    );
    $wp_customize->add_control( new Yaatra_Mag_Toggle_Checkbox_Custom_Control(
        $wp_customize, 
        'yaatra_mag_enable_related_posts',
            array(
                'label'         => __( 'Related Posts Option', 'yaatra-mag' ),
                'description'   => __( 'Option to show/hide related posts.', 'yaatra-mag' ),
                'section'       => 'yaatra_mag_post_section',
                'settings'      => 'yaatra_mag_enable_related_posts',
                'priority'      => 10
            )
        )
    );
    
    /**
     * Text field for related posts section at post page
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'related_posts_title',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => __( 'Related Posts', 'yaatra-mag' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
        'related_posts_title',
            array(
                'label'         => __( 'Related Posts Title', 'yaatra-mag' ),
                'type'          => 'text',
                'section'       => 'yaatra_mag_post_section',
                'settings'      => 'related_posts_title',
                'priority'      => 15,
                'active_callback'   => 'yaatra_mag_enable_related_posts_active_callback'
            )
        );

    /**
     * Number for related posts section at post page
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yaatra_mag_related_posts_count',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => 3,
            'sanitize_callback' => 'absint',
        )
    );
    $wp_customize->add_control(
        'yaatra_mag_related_posts_count',
            array(
                'label'         => __( 'No.of Related Posts to display', 'yaatra-mag' ),
                'type'          => 'number',
                'section'       => 'yaatra_mag_post_section',
                'settings'      => 'yaatra_mag_related_posts_count',
                'priority'      => 20,
                'active_callback'   => 'yaatra_mag_enable_related_posts_active_callback'
            )
        );

    /**
     * Select field for related post orderby
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'yaatra_mag_related_posts_orderby',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => 'rp_default',
            'sanitize_callback' => 'yaatra_mag_sanitize_select',
        )
    );
    $wp_customize->add_control(
        'yaatra_mag_related_posts_orderby',
        array(
            'label'         => __( 'Post orderby', 'yaatra-mag' ),
            'section'       => 'yaatra_mag_post_section',
            'settings'      => 'yaatra_mag_related_posts_orderby',
            'type'          => 'select',
            'priority'      => 25,
            'choices'       => array(
                'rp_default'     => __( 'Default', 'yaatra-mag' ),
                'rp_rand' => __( 'Random', 'yaatra-mag' )
            ),
            'active_callback'   => 'yaatra_mag_enable_related_posts_active_callback'
        )
    );

}