<?php
/**
 * Yaatra Mag Header Settings panel at Theme Customizer
 *
 * @package CodeVibrant
 * @subpackage Yaatra Mag
 * @since 1.0.0
 */

add_action( 'customize_register', 'yaatra_mag_header_settings_register' );

function yaatra_mag_header_settings_register( $wp_customize ) {

	$wp_customize->get_section( 'header_image' )->panel = 'yaatra_mag_header_settings_panel';
	$wp_customize->get_section( 'header_image' )->title = __( 'Innerpages Header Image', 'yaatra-mag' );
    $wp_customize->get_section( 'header_image' )->priority = '25';

    /**
     * Add Header Settings Panel
     *
     * @since 1.0.0
     */
    $wp_customize->add_panel(
	    'yaatra_mag_header_settings_panel',
	    array(
	        'priority'       => 10,
	        'capability'     => 'edit_theme_options',
	        'theme_supports' => '',
	        'title'          => __( 'Header Settings', 'yaatra-mag' ),
	    )
    );

	/*--------------------------------------------------------------------------------------------------------------------*/
	/**
     * Header Style section
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'yaatra_mag_header_style_section',
        array(
        	'priority'       => 5,
        	'panel'          => 'yaatra_mag_header_settings_panel',
        	'capability'     => 'edit_theme_options',
        	'theme_supports' => '',
            'title'          => __( 'Style', 'yaatra-mag' )
        )
    );
    
    /**
     * Heading field for Header Style
     *
     * Header Settings > Style
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting( 'yaatra_mag_header_background_heading',
        array(
            'capability'        => 'edit_theme_options',
            'theme_options'     => '',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );

    $wp_customize->add_control( new Yaatra_Mag_Heading_Controler(
        $wp_customize, 'yaatra_mag_header_background_heading',
            array(
                'priority'      => 10,
                'section'       => 'yaatra_mag_header_style_section',
                'settings'      => 'yaatra_mag_header_background_heading',
                'label'         => __( 'Background Settings', 'yaatra-mag' ),
            )
        )
    );
    
    /**
     * Color option for header background
     *
     * Header Settings > Style
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting( 'yaatra_mag_header_background_color',
        array(
            'capability'        => 'edit_theme_options',
            'theme_options'     => '',
            'default'           => '#ffffff',
            'sanitize_callback' => 'yaatra_mag_sanitize_alpha_color'
        )
    );

    $wp_customize->add_control( new Yaatra_Mag_Control_Color(
        $wp_customize, 'yaatra_mag_header_background_color',
            array(
                'priority'          => 40,
                'section'           => 'yaatra_mag_header_style_section',
                'settings'          => 'yaatra_mag_header_background_color',
                'label'             => __( 'Header Background Color', 'yaatra-mag' )
            )
        )
    );

    /**
     * Color option for header text color
     *
     * Theme Options > Header > Style
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting( 'yaatra_mag_header_text_color',
        array(
            'capability'        => 'edit_theme_options',
            'theme_options'     => '',
            'default'           => '#3d3d3d',
            'sanitize_callback' => 'yaatra_mag_sanitize_alpha_color'
        )
    );

    $wp_customize->add_control( new Yaatra_Mag_Control_Color(
        $wp_customize, 'yaatra_mag_header_text_color',
            array(
                'priority'          => 50,
                'section'           => 'yaatra_mag_header_style_section',
                'settings'          => 'yaatra_mag_header_text_color',
                'label'             => __( 'Header Text Color', 'yaatra-mag' )
            )
        )
    );

}