<?php
/**
 * Functions for rendering meta boxes in page
 * 
 * @package CodeVibrant
 * @subpackage Yaatra Mag
 * @since 1.0.0
 */

/*----------------------------------------------------------------------------------------------------------------------------------------*/

add_action( 'add_meta_boxes', 'yaatra_mag_page_metaboxes', 10, 2 );
function yaatra_mag_page_metaboxes() {
    add_meta_box(
        'yaatra_page_meta',
        __( 'Yaatra Mag Meta', 'yaatra-mag' ),
        'yaatra_mag_page_meta_callback',
        'page',
        'normal',
        'default'
    );
}

/*----------------------------------------------------------------------------------------------------------------------------------------*/
function yaatra_mag_page_meta_callback( $post ) {

    // Setup our options.
    $yaatra_mag_page_sidebar_option = array(
        'default-sidebar' => array(
            'id'        => 'post-default-sidebar',
            'value'     => 'default_sidebar',
            'label'     => __( 'Default Sidebar', 'yaatra-mag' ),
            'thumbnail' => get_template_directory_uri() . '/assets/images/default-sidebar.png'
        ),
        'left-sidebar' => array(
            'id'        => 'post-left-sidebar',
            'value'     => 'left_sidebar',
            'label'     => __( 'Left sidebar', 'yaatra-mag' ),
            'thumbnail' => get_template_directory_uri() . '/assets/images/left-sidebar.png'
        ),
        'right-sidebar' => array(
            'id'        => 'post-right-sidebar',
            'value'     => 'right_sidebar',
            'label'     => __( 'Right sidebar', 'yaatra-mag' ),
            'thumbnail' => get_template_directory_uri() . '/assets/images/right-sidebar.png'
        ),
        'no-sidebar'    => array(
            'id'        => 'post-no-sidebar',
            'value'     => 'no_sidebar',
            'label'     => __( 'No sidebar Full width', 'yaatra-mag' ),
            'thumbnail' => get_template_directory_uri() . '/assets/images/no-sidebar.png'
        ),
        'no-sidebar-center' => array(
            'id'        => 'post-no-sidebar-center',
            'value'     => 'no_sidebar_center',
            'label'     => __( 'No sidebar Content Centered', 'yaatra-mag' ),
            'thumbnail' => get_template_directory_uri() . '/assets/images/no-sidebar-center.png'
        )
    );

    $yaatra_mag_post_styles_option = array(
        'default-style' => array(
            'id'        => 'post-default-style',
            'value'     => 'default_style',
            'label'     => __( 'Default Style', 'yaatra-mag' ),
            'thumbnail' => get_template_directory_uri() . '/assets/images/default-sidebar.png'
        ),
        'post-style-one' => array(
            'id'        => 'post-style-one',
            'value'     => 'style_one',
            'label'     => __( 'Style One', 'yaatra-mag' ),
            'thumbnail' => get_template_directory_uri() . '/assets/images/left-sidebar.png'
        ),
        'post-style-two' => array(
            'id'        => 'post-style-two',
            'value'     => 'style_two',
            'label'     => __( 'Style Two', 'yaatra-mag' ),
            'thumbnail' => get_template_directory_uri() . '/assets/images/left-sidebar.png'
        )
    );

    // Check for previously set.
    $sidebar_layout = get_post_meta( $post->ID, 'yaatra_mag_sidebar_layout', true );

    // If it is then we use it otherwise set to default.
    $sidebar_layout = ( $sidebar_layout ) ? $sidebar_layout : 'default_sidebar';

    // Check for previously set.
    $yaatra_mag_post_style = get_post_meta( $post->ID, 'yaatra_mag_post_style', true );

    // If it is then we use it otherwise set to default.
    $yaatra_mag_post_style = ( $yaatra_mag_post_style ) ? $yaatra_mag_post_style : 'default_style';

    // Create our nonce field.
    wp_nonce_field( 'yaatra_mag_nonce_' . basename( __FILE__ ) , 'yaatra_mag_post_meta_nonce' );
    ?>
        <div class="cv-meta-options-wrap">
            <ul class="cv-meta-menu-wrapper">
                <li class="cv-meta-tab <?php if ( $post_identity_value == 'cv-metabox-info' ) { echo 'active'; } ?>" data-tab="cv-metabox-info"><span class="dashicons dashicons-info"></span><?php esc_html_e( 'Information', 'yaatra-mag' ); ?></li>
                <li class="cv-meta-tab <?php if ( $post_identity_value == 'cv-metabox-sidebar' ) { echo 'active'; } ?>" data-tab="cv-metabox-sidebar"><span class="dashicons dashicons-exerpt-view"></span><?php esc_html_e( 'Sidebars', 'yaatra-mag' ); ?></li>
                <li class="cv-meta-tab <?php if ( $post_identity_value == 'cv-metabox-styles' ) { echo 'active'; } ?>" data-tab="cv-metabox-styles"><span class="dashicons dashicons-heading"></span><?php esc_html_e( 'Post Styles Settings', 'yaatra-mag' ); ?></li>
            </ul>

            <div class="cv-metabox-content-wrapper">
                <!-- Info tab content -->
                <div class="cv-single-meta <?php if ( $post_identity_value == 'cv-metabox-info' ) { echo 'active'; } ?>" id="cv-metabox-info">
                    <div class="content-header">
                        <h4 class="cv-meta-heading"><?php esc_html_e( 'About Metabox Options', 'yaatra-mag' ) ;?></h4>
                    </div><!-- .content-header -->
                    <div class="meta-options-wrap"><?php esc_html_e( 'In this section we have lots of features which make your post unique and completely different.', 'yaatra-mag' ); ?></div><!-- .meta-options-wrap  -->
                </div><!-- #cv-metabox-info -->

                <div class="cv-single-meta" id="cv-metabox-sidebar" style="display:none">
                    <div class="content-header">
                        <h4 class="cv-meta-heading"><?php esc_html_e( 'Manage sidebar layouts of this post', 'yaatra-mag' ) ;?></h4>
                    </div><!-- .content-header -->
                    <div class="buttonset">
                        <?php
                            foreach ( $yaatra_mag_page_sidebar_option as $field ) {
                                $sidebar_layout = get_post_meta( $post->ID, 'yaatra_mag_sidebar_layout', true );
                                $sidebar_layout = ( $sidebar_layout ) ? $sidebar_layout : 'default_sidebar';
                        ?>
                                <input type="radio" id="<?php echo esc_attr( $field['id'] ); ?>" value="<?php echo esc_attr( $field['value'] ); ?>" name="yaatra_mag_sidebar_layout" <?php checked( $field['value'], $sidebar_layout ); ?> />
                                <label for="<?php echo esc_attr( $field['id'] ); ?>">
                                    <span class="screen-reader-text"><?php echo esc_html( $field['label'] ); ?></span>
                                    <img src="<?php echo esc_url( $field['thumbnail'] ); ?>" title="<?php echo esc_attr( $field['label'] ); ?>" alt="<?php echo esc_attr( $field['label'] ); ?>" />
                                </label>
                            
                        <?php } ?>
                    </div><!-- .buttonset -->
                </div><!-- #cv-metabox-sidebar -->

                <div class="cv-single-meta" id="cv-metabox-styles" style="display:none">
                    <div class="content-header">
                        <h4 class="cv-meta-heading"><?php esc_html_e( 'Manage post style for this post', 'yaatra-mag' ) ;?></h4>
                    </div><!-- .content-header -->
                    <div class="buttonset">
                        <?php
                            foreach ( $yaatra_mag_post_styles_option as $field ) {
                                $yaatra_mag_post_style = get_post_meta( $post->ID, 'yaatra_mag_post_style', true );
                                $yaatra_mag_post_style = ( $yaatra_mag_post_style ) ? $yaatra_mag_post_style : 'default_style';
                        ?>
                                <input type="radio" id="<?php echo esc_attr( $field['id'] ); ?>" value="<?php echo esc_attr( $field['value'] ); ?>" name="yaatra_mag_post_style" <?php checked( $field['value'], $yaatra_mag_post_style ); ?> />
                                <label for="<?php echo esc_attr( $field['id'] ); ?>">
                                    <span class="screen-reader-text"><?php echo esc_html( $field['label'] ); ?></span>
                                    <img src="<?php echo esc_url( $field['thumbnail'] ); ?>" title="<?php echo esc_attr( $field['label'] ); ?>" alt="<?php echo esc_attr( $field['label'] ); ?>" />
                                </label>
                            
                        <?php } ?>
                    </div><!-- .buttonset -->
                </div><!-- #cv-metabox-styles -->

            </div><!-- .cv-metabox-content-wrapper -->
        </div><!-- .cv-meta-options-wrap  -->
    <?php
}

/*----------------------------------------------------------------------------------------------------------------------------------------*/
add_action( 'save_post', 'yaatra_mag_page_save_post_meta' );

function yaatra_mag_page_save_post_meta( $post_id ) {
    // Checks save status
    $is_autosave = wp_is_post_autosave( $post_id );
    $is_revision = wp_is_post_revision( $post_id );
    $is_valid_nonce = ( isset( $_POST['yaatra_mag_post_meta_nonce'] ) && wp_verify_nonce( $_POST['yaatra_mag_post_meta_nonce'], 'yaatra_mag_nonce_' . basename( __FILE__ ) ) ) ? 'true' : 'false';

    // Exits script depending on save status
    if ( $is_autosave || $is_revision || ! $is_valid_nonce ) {
        return;
    }

    // Check for out input value.
    if ( isset( $_POST['yaatra_mag_sidebar_layout'] ) ) {
        
        // We validate making sure that the option is something we can expect.
        $value = in_array( $_POST['yaatra_mag_sidebar_layout'], array( 'no_sidebar', 'left_sidebar', 'right_sidebar', 'no_sidebar_center', 'default_sidebar' ) ) ? $_POST['yaatra_mag_sidebar_layout'] : 'default_sidebar';
        
        // We update our post meta.
        update_post_meta( $post_id, 'yaatra_mag_sidebar_layout', $value );
    }

    // Check for out input value.
    if ( isset( $_POST['yaatra_mag_post_style'] ) ) {
        
        // We validate making sure that the option is something we can expect.
        $value = in_array( $_POST['yaatra_mag_post_style'], array( 'default_style', 'style_one', 'style_two' ) ) ? $_POST['yaatra_mag_post_style'] : 'default_style';
        
        // We update our post meta.
        update_post_meta( $post_id, 'yaatra_mag_post_style', $value );
    }
}