<?php
/**
 * CV: Author Info
 *
 * Widget show the author information
 *
 * @package CodeVibrant
 * @subpackage Yaatra Mag
 * @since 1.0.0
 */

class Yaatra_Mag_Advertisement_Banner extends WP_widget {

	/**
     * Register widget with WordPress.
     */
    public function __construct() {
        $widget_ops = array( 
            'classname'     => 'yaatra_mag_advertisement_banner',
            'description'   => __( 'Select the user to display the advertisement banner.', 'yaatra-mag' ),
            'customize_selective_refresh'   => true,
        );
        parent::__construct( 'yaatra_mag_advertisement_banner', __( 'CV: Advertisement Banner', 'yaatra-mag' ), $widget_ops );
    }

    /**
     * Helper function that holds widget fields
     * Array is used in update and form functions
     */
    private function widget_fields() {
        
        $fields = array(

            'widget_title' => array(
                'yaatra_mag_widgets_name'         => 'widget_title',
                'yaatra_mag_widgets_title'        => __( 'Widget title', 'yaatra-mag' ),
                'yaatra_mag_widgets_field_type'   => 'text'
            ),
            'section_image' => array(
                'yaatra_mag_widgets_name' => 'section_image',
                'yaatra_mag_widgets_title' => __( 'Section Image', 'yaatra-mag' ),
                'yaatra_mag_widgets_field_type' => 'upload',
            ),
            'section_image_url' => array(
                'yaatra_mag_widgets_name'         => 'section_image_url',
                'yaatra_mag_widgets_title'        => __( 'URL', 'yaatra-mag' ),
                'yaatra_mag_widgets_field_type'   => 'url'
            )
        );
        return $fields;
    }

    /**
     * Front-end display of widget.
     *
     * @see WP_Widget::widget()
     *
     * @param array $args     Widget arguments.
     * @param array $instance Saved values from database.
     */
    public function widget( $args, $instance ) {
        extract( $args );
        if ( empty( $instance ) ) {
            return ;
        }

        $yaatra_mag_widget_title    = empty( $instance['widget_title'] ) ? '' : $instance['widget_title'];
        $section_image              = empty( $instance['section_image'] ) ? '' : $instance['section_image'];
        $section_image_url              = empty( $instance['section_image_url'] ) ? '' : $instance['section_image_url'];

        echo $before_widget;
    ?>
            <div class="cv-advertisement-banner-wrapper">
                <?php
                    if ( !empty( $yaatra_mag_widget_title ) ) {
                        echo $before_title . esc_html( $yaatra_mag_widget_title ) . $after_title;
                    }
                ?>
                <div class="advertisement-banner-content">
                    <?php 
                        if ( $section_image_url ) {
                            echo '<a href="' .esc_url( $section_image_url ). '" target="_blank"><img src="' .esc_url( $section_image ). '"></a>';
                        } else {
                            echo '<img src="' .esc_url( $section_image ). '">';
                        }
                    ?>
                </div><!-- .advertisement-banner-content -->
            </div><!-- .cv-advertisement-banner-wrapper -->
    <?php
        echo $after_widget;
    }

    /**
     * Sanitize widget form values as they are saved.
     *
     * @see WP_Widget::update()
     *
     * @param   array   $new_instance   Values just sent to be saved.
     * @param   array   $old_instance   Previously saved values from database.
     *
     * @uses    yaatra_mag_widgets_updated_field_value()     defined in cv-widget-fields.php
     *
     * @return  array Updated safe values to be saved.
     */
    public function update( $new_instance, $old_instance ) {
        $instance = $old_instance;

        $widget_fields = $this->widget_fields();

        // Loop through fields
        foreach ( $widget_fields as $widget_field ) {

            extract( $widget_field );

            // Use helper function to get updated field values
            $instance[$yaatra_mag_widgets_name] = yaatra_mag_widgets_updated_field_value( $widget_field, $new_instance[$yaatra_mag_widgets_name] );
        }

        return $instance;
    }

    /**
     * Back-end widget form.
     *
     * @see WP_Widget::form()
     *
     * @param   array $instance Previously saved values from database.
     *
     * @uses    yaatra_mag_widgets_show_widget_field()       defined in cv-widget-fields.php
     */
    public function form( $instance ) {
        $widget_fields = $this->widget_fields();

        // Loop through fields
        foreach ( $widget_fields as $widget_field ) {

            // Make array elements available as variables
            extract( $widget_field );
            $yaatra_mag_widgets_field_value = !empty( $instance[$yaatra_mag_widgets_name] ) ? wp_kses_post( $instance[$yaatra_mag_widgets_name] ) : '';
            yaatra_mag_widgets_show_widget_field( $this, $widget_field, $yaatra_mag_widgets_field_value );
        }
    }
}